==> style-o-matic-1.1.5.tgz: package/es/components/Dropdown/DropdownContent.js <==
var _class, _temp2;

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import React, { cloneElement } from "react";
import { CoreComponent, getValidProps, setCorePropDefaults, ROLE } from "../../lib";

var DropdownContent = (_temp2 = _class = function (_CoreComponent) {
  _inherits(DropdownContent, _CoreComponent);

  function DropdownContent() {
    var _temp, _this, _ret;

    _classCallCheck(this, DropdownContent);

    for (var _len = arguments.length, args = Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }

    return _ret = (_temp = (_this = _possibleConstructorReturn(this, _CoreComponent.call.apply(_CoreComponent, [this].concat(args))), _this), _this.items = [], _this.renderChild = function (child, props) {
      var ref = function ref(c) {
        _this.items.push(c);
      };
      if (typeof child.ref !== "string") {
        ref = _this.chainFunction(child.ref, ref);
      }
      return cloneElement(child, {
        ref: ref,
        className: "ui-dropdown-item"
      });
    }, _temp), _possibleConstructorReturn(_this, _ret);
  }

  DropdownContent.prototype.render = function render() {
    var _this2 = this;

    var _getValidProps = getValidProps(this.props),
        Component = _getValidProps.renderAs,
        children = _getValidProps.children,
        props = _getValidProps.props,
        inherited = _getValidProps.inherited;

    this.items = [];

    return React.createElement(
      Component,
      props,
      React.Children.map(children, function (child) {
        return _this2.renderChild(child, inherited);
      })
    );
  };

  return DropdownContent;
}(CoreComponent), _class.defaultProps = setCorePropDefaults({
  renderAs: "div",
  uirole: ROLE.CONTENT
}), _temp2);


export default DropdownContent;

==> style-o-matic-1.1.37.tgz: package/es/components/Dropdown/DropdownContent.js <==
var _class, _temp2;

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import React, { cloneElement } from "react";
import { CoreComponent, getValidProps, getCorePropDefaults, ROLE } from "../../lib";

var DropdownContent = (_temp2 = _class = function (_CoreComponent) {
  _inherits(DropdownContent, _CoreComponent);

  function DropdownContent() {
    var _temp, _this, _ret;

    _classCallCheck(this, DropdownContent);

    for (var _len = arguments.length, args = Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }

    return _ret = (_temp = (_this = _possibleConstructorReturn(this, _CoreComponent.call.apply(_CoreComponent, [this].concat(args))), _this), _this.items = [], _this.renderChild = function (child, props) {
      var ref = function ref(c) {
        _this.items.push(c);
      };
      if (typeof child.ref !== "string") {
        ref = _this.chainFunction(child.ref, ref);
      }
      return cloneElement(child, {
        ref: ref,
        className: "ui-dropdown-item"
      });
    }, _temp), _possibleConstructorReturn(_this, _ret);
  }

  DropdownContent.prototype.render = function render() {
    var _this2 = this;

    var _getValidProps = getValidProps(this.props),
        Component = _getValidProps.renderAs,
        children = _getValidProps.children,
        props = _getValidProps.props,
        inherited = _getValidProps.inherited;

    this.items = [];

    return React.createElement(
      Component,
      props,
      React.Children.map(children, function (child) {
        return _this2.renderChild(child, inherited);
      })
    );
  };

  return DropdownContent;
}(CoreComponent), _class.defaultProps = getCorePropDefaults({
  renderAs: "div",
  uirole: ROLE.CONTENT
}), _temp2);


export default DropdownContent;
